 ![PowerBot Logo](https://www.powerbot-trading.com/wp-content/uploads/2018/03/PowerBot_Weblogo.png "PowerBot")
# **PowerBot Backtesting**
#### ***All of PowerBot's backtesting functions in one package***

***
## Introduction
In general, the functions contained in PowerbotBacktesting are designed to make the process of loading, processing,
analysing and visualizing market data as simple as possible. With a few line of code you can load contracts within
a certain timeframe and utilize their IDs to load all relevant additional data like Revisions (including Orders), 
Trades, etc.. This data can then be used to process orderbooks and OHLC-data and subsequently visualize them. There
are also functions to run simple backtesting strategies, but these should be understood as templates to refine a 
strategy of your own.

For a more detailed documentation, please visit our [Knowlegde Base](https://docs.powerbot-trading.com/articles/backtesting/).

To see some exemplary scripts on how to use the functions in this package, please check out our 
[PowerBot Tools](https://github.com/powerbot-trading/powerbot_tools).
***